KeyCode

Enum KeyCode 

pub enum KeyCode {
Show 27 variants Backspace, Enter, Left, Right, Up, Down, Home, End, PageUp, PageDown, Tab, BackTab, Delete, Insert, F(u8), Char(char), Null, Esc, CapsLock, ScrollLock, NumLock, PrintScreen, Pause, Menu, KeypadBegin, Media(MediaKeyCode), Modifier(ModifierKeyCode),
}
Represents a key.

Variants



Backspace

Backspace key (Delete on macOS, Backspace on other platforms).



Enter

Enter key.



Left

Left arrow key.



Right

Right arrow key.



Up

Up arrow key.



Down

Down arrow key.



Home

Home key.



End

End key.



PageUp

Page up key.



PageDown

Page down key.



Tab

Tab key.



BackTab

Shift + Tab key.



Delete

Delete key. (Fn+Delete on macOS, Delete on other platforms)



Insert

Insert key.



F(u8)

F key.

KeyCode::F(1) represents F1 key, etc.



Char(char)

A character.

KeyCode::Char('c') represents c character, etc.



Null

Null.



Esc

Escape key.



CapsLock

Caps Lock key.

Note: this key can only be read if KeyboardEnhancementFlags::DISAMBIGUATE_ESCAPE_CODES has been enabled with PushKeyboardEnhancementFlags.



ScrollLock

Scroll Lock key.

Note: this key can only be read if KeyboardEnhancementFlags::DISAMBIGUATE_ESCAPE_CODES has been enabled with PushKeyboardEnhancementFlags.



NumLock

Num Lock key.

Note: this key can only be read if KeyboardEnhancementFlags::DISAMBIGUATE_ESCAPE_CODES has been enabled with PushKeyboardEnhancementFlags.



PrintScreen

Print Screen key.

Note: this key can only be read if KeyboardEnhancementFlags::DISAMBIGUATE_ESCAPE_CODES has been enabled with PushKeyboardEnhancementFlags.



Pause

Pause key.

Note: this key can only be read if KeyboardEnhancementFlags::DISAMBIGUATE_ESCAPE_CODES has been enabled with PushKeyboardEnhancementFlags.



Menu

Menu key.

Note: this key can only be read if KeyboardEnhancementFlags::DISAMBIGUATE_ESCAPE_CODES has been enabled with PushKeyboardEnhancementFlags.



KeypadBegin

The “Begin” key (often mapped to the 5 key when Num Lock is turned on).

Note: this key can only be read if KeyboardEnhancementFlags::DISAMBIGUATE_ESCAPE_CODES has been enabled with PushKeyboardEnhancementFlags.



Media(MediaKeyCode)

A media key.

Note: these keys can only be read if KeyboardEnhancementFlags::DISAMBIGUATE_ESCAPE_CODES has been enabled with PushKeyboardEnhancementFlags.



Modifier(ModifierKeyCode)

Implementations

Source

impl KeyCode

pub const fn is_backspace(&self) -> bool

Returns true if this value is of type Backspace. Returns false otherwise

pub const fn is_enter(&self) -> bool

Returns true if this value is of type Enter. Returns false otherwise

pub const fn is_left(&self) -> bool

Returns true if this value is of type Left. Returns false otherwise

pub const fn is_right(&self) -> bool

Returns true if this value is of type Right. Returns false otherwise

pub const fn is_up(&self) -> bool

Returns true if this value is of type Up. Returns false otherwise

pub const fn is_down(&self) -> bool

Returns true if this value is of type Down. Returns false otherwise

pub const fn is_home(&self) -> bool

Returns true if this value is of type Home. Returns false otherwise

pub const fn is_end(&self) -> bool

Returns true if this value is of type End. Returns false otherwise

pub const fn is_page_up(&self) -> bool

Returns true if this value is of type PageUp. Returns false otherwise

pub const fn is_page_down(&self) -> bool

Returns true if this value is of type PageDown. Returns false otherwise

pub const fn is_tab(&self) -> bool

Returns true if this value is of type Tab. Returns false otherwise

pub const fn is_back_tab(&self) -> bool

Returns true if this value is of type BackTab. Returns false otherwise

pub const fn is_delete(&self) -> bool

Returns true if this value is of type Delete. Returns false otherwise

pub const fn is_insert(&self) -> bool

Returns true if this value is of type Insert. Returns false otherwise

pub const fn is_null(&self) -> bool

Returns true if this value is of type Null. Returns false otherwise

pub const fn is_esc(&self) -> bool

Returns true if this value is of type Esc. Returns false otherwise

pub const fn is_caps_lock(&self) -> bool

Returns true if this value is of type CapsLock. Returns false otherwise

pub const fn is_scroll_lock(&self) -> bool

Returns true if this value is of type ScrollLock. Returns false otherwise

pub const fn is_num_lock(&self) -> bool

Returns true if this value is of type NumLock. Returns false otherwise

pub const fn is_print_screen(&self) -> bool

Returns true if this value is of type PrintScreen. Returns false otherwise

pub const fn is_pause(&self) -> bool

Returns true if this value is of type Pause. Returns false otherwise

pub const fn is_menu(&self) -> bool

Returns true if this value is of type Menu. Returns false otherwise

pub const fn is_keypad_begin(&self) -> bool

Returns true if this value is of type KeypadBegin. Returns false otherwise

Source

impl KeyCode

pub fn is_function_key(&self, n: u8) -> bool

Returns true if the key code is the given function key.

Examples
assert!(KeyCode::F(1).is_function_key(1));
assert!(!KeyCode::F(1).is_function_key(2));
pub fn is_char(&self, c: char) -> bool

Returns true if the key code is the given character.

Examples
assert!(KeyCode::Char('a').is_char('a'));
assert!(!KeyCode::Char('a').is_char('b'));
assert!(!KeyCode::F(1).is_char('a'));
pub fn as_char(&self) -> Option<char>

Returns the character if the key code is a character key.

Returns None if the key code is not a character key.

Examples
assert_eq!(KeyCode::Char('a').as_char(), Some('a'));
assert_eq!(KeyCode::F(1).as_char(), None);
pub fn is_media_key(&self, media: MediaKeyCode) -> bool

Returns true if the key code is the given media key.

Note: this method requires KeyboardEnhancementFlags::DISAMBIGUATE_ESCAPE_CODES to be enabled with PushKeyboardEnhancementFlags.

Examples
assert!(KeyCode::Media(MediaKeyCode::Play).is_media_key(MediaKeyCode::Play));
assert!(!KeyCode::Media(MediaKeyCode::Play).is_media_key(MediaKeyCode::Pause));
pub fn is_modifier(&self, modifier: ModifierKeyCode) -> bool

Returns true if the key code is the given modifier key.

Note: this method requires both KeyboardEnhancementFlags::DISAMBIGUATE_ESCAPE_CODES and KeyboardEnhancementFlags::REPORT_ALL_KEYS_AS_ESCAPE_CODES to be enabled with PushKeyboardEnhancementFlags.

Examples
assert!(KeyCode::Modifier(ModifierKeyCode::LeftShift).is_modifier(ModifierKeyCode::LeftShift));
assert!(!KeyCode::Modifier(ModifierKeyCode::LeftShift).is_modifier(ModifierKeyCode::RightShift));